# Generated by Django 4.0.3 on 2022-03-13 11:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('esi', '0010_set_new_tokens_to_sso_v2'),
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0008_alter_order_state'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Config',
            new_name='PublicConfig',
        ),
        migrations.AddField(
            model_name='order',
            name='source_character',
            field=models.BooleanField(default=False, verbose_name='Sourced From Character API Market Data'),
        ),
        migrations.AddField(
            model_name='order',
            name='source_corporation',
            field=models.BooleanField(default=False, verbose_name='Sourced From Corporation API Market Data'),
        ),
        migrations.AddField(
            model_name='order',
            name='source_public',
            field=models.BooleanField(default=False, verbose_name='Sourced From Public Market Data'),
        ),
        migrations.AlterField(
            model_name='structure',
            name='owner_id',
            field=models.IntegerField(verbose_name='Owner Corporation ID'),
        ),
        migrations.CreateModel(
            name='PrivateConfig',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('failed', models.BooleanField(verbose_name='')),
                ('failure_reason', models.CharField(max_length=50, verbose_name='')),
                ('token', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='esi.token', verbose_name='ESI Token')),
                ('valid_corporations', models.ManyToManyField(to='eveonline.evecorporationinfo', verbose_name='Valid Corporation Markets for this Token')),
                ('valid_structures', models.ManyToManyField(to='marketmanager.structure', verbose_name='Valid Structure Markets for this Token')),
            ],
            options={
                'default_permissions': (),
            },
        ),
    ]
