# Generated by Django 4.0.3 on 2022-03-18 10:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0018_remove_typestatistics_buy_5_percent_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='order',
            name='escrow',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_character',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_corporation',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_private',
        ),
        migrations.RemoveField(
            model_name='order',
            name='source_public',
        ),
        migrations.RemoveField(
            model_name='order',
            name='volume_total',
        ),
    ]
