# Generated by Django 3.2.8 on 2021-11-29 13:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='config',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='order',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='structure',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='watchconfig',
            options={'default_permissions': ()},
        ),
        migrations.AlterModelOptions(
            name='webhook',
            options={'default_permissions': ()},
        ),
    ]
