# Generated by Django 4.0.3 on 2022-03-19 06:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0022_remove_typestatistics_evetypeeveregiontypestatistic'),
    ]

    operations = [
        migrations.AlterField(
            model_name='typestatistics',
            name='eve_region',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.everegion', verbose_name=''),
        ),
    ]
