# Generated by Django 4.0.3 on 2022-03-13 13:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0010_order_source_private'),
    ]

    operations = [
        migrations.AlterField(
            model_name='privateconfig',
            name='failed',
            field=models.BooleanField(verbose_name='Disabled due to Failure, Check reason, adjust config and re-enable'),
        ),
        migrations.AlterField(
            model_name='privateconfig',
            name='failure_reason',
            field=models.CharField(max_length=100, verbose_name='Failure Reason'),
        ),
    ]
