# Generated by Django 3.2.8 on 2021-11-30 14:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('marketmanager', '0004_alter_order_wallet_division'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_market_browser', 'Can access the Market Browser with standard features'), ('order_highlight_user', "Market orders owned by the user's characters may be highlighted in the standard/basic Market Browser"), ('order_highlight_corporation', 'Market orders owned by any corporation a user is a member of may be highlighted in the standard/basic Market Browser WARNING: This has no checks for Corporation Roles.'), ('advanced_market_browser', 'Can access the Market Browser with more detail such as the owners of orders'))},
        ),
    ]
