# Generated by Django 4.0.3 on 2022-03-15 14:23

from decimal import Decimal

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('esi', '0010_set_new_tokens_to_sso_v2'),
        ('marketmanager', '0013_watchconfig_managed_app_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='watchconfig',
            name='price',
            field=models.DecimalField(decimal_places=2, default=Decimal('0'), help_text='Set to Zero to skip this filter', max_digits=20, verbose_name='Price'),
        ),
        migrations.CreateModel(
            name='TypeStatistics',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('buy_5_percent', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_5_percent', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('buy_weighted_average', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_weighted_average', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('buy_median', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('sell_median', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='')),
                ('eve_type', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='esi.token', verbose_name='ESI Token')),
            ],
            options={
                'default_permissions': (),
            },
        ),
    ]
