# Generated by Django 3.2.8 on 2021-12-01 13:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0005_type_materials_and_sections'),
        ('marketmanager', '0005_alter_general_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='structure',
            name='eve_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='eveuniverse.evetype', verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='constellation',
            field=models.ManyToManyField(to='eveuniverse.EveConstellation', verbose_name='Constellation'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='location',
            field=models.ManyToManyField(to='marketmanager.Structure', verbose_name='Structure'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='region',
            field=models.ManyToManyField(to='eveuniverse.EveRegion', verbose_name='Region'),
        ),
        migrations.AlterField(
            model_name='watchconfig',
            name='solar_system',
            field=models.ManyToManyField(to='eveuniverse.EveSolarSystem', verbose_name='Solar System'),
        ),
    ]
